@@ -10,28 +10,34 @@ import (
 )
 
 func NewCmdDebug() *cobra.Command {
+	cmd := &cobra.Command{
+		Use:     "debug",
+		Short:   "debug site details",
+		Long:    "debug site details",
+		Example: "skupper debug dump <filename>",
+	}
 	platform := common.Platform(config.GetPlatform())
-	cmd := CmdDebugFactory(platform)
+	cmd.AddCommand(CmdDebugDumpFactory(platform))
 
 	return cmd
 }
 
-func CmdDebugFactory(configuredPlatform common.Platform) *cobra.Command {
+func CmdDebugDumpFactory(configuredPlatform common.Platform) *cobra.Command {
 	kubeCommand := kube.NewCmdDebug()
 	nonKubeCommand := nonkube.NewCmdDebug()
 
 	cmdDebugDesc := common.SkupperCmdDescription{
-		Use:   "debug",
-		Short: "",
-		Long:  "",
+		Use:   "dump <fileName>",
+		Short: "Create a tarball containing various files with the site details",
+		Long: `Create a tarball including site resources and status; component versions, config files, 
+	and logs; and info about the environment where Skupper is running`,
+		Example: "skupper debug dump <filename>",
 	}
 
 	cmd := common.ConfigureCobraCommand(configuredPlatform, cmdDebugDesc, kubeCommand, nonKubeCommand)
 
 	cmdFlags := common.CommandDebugFlags{}
 
-	//Add flags if necessary
-
 	kubeCommand.CobraCmd = cmd
 	kubeCommand.Flags = &cmdFlags
 	nonKubeCommand.CobraCmd = cmd
