@@ -11,6 +11,7 @@ import (
 	"github.com/skupperproject/skupper/pkg/apis/skupper/v2alpha1"
 	"gotest.tools/v3/assert"
 	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 )
@@ -23,9 +24,17 @@ func TestCmdLinkGenerate_ValidateInput(t *testing.T) {
 		k8sObjects     []runtime.Object
 		skupperObjects []runtime.Object
 		expectedError  string
+		skupperError   string
 	}
 
 	testTable := []test{
+		{
+			name:          "missing CRD",
+			args:          []string{"my-connector", "8080"},
+			flags:         common.CommandLinkGenerateFlags{},
+			skupperError:  utils.CrdErr,
+			expectedError: utils.CrdHelpErr,
+		},
 		{
 			name: "link yaml is not generated because there is no site in the namespace.",
 			expectedError: "there is no skupper site in this namespace\n" +
@@ -402,7 +411,7 @@ func TestCmdLinkGenerate_ValidateInput(t *testing.T) {
 	for _, test := range testTable {
 		t.Run(test.name, func(t *testing.T) {
 
-			command, err := newCmdLinkGenerateWithMocks("test", nil, test.skupperObjects, "")
+			command, err := newCmdLinkGenerateWithMocks("test", nil, test.skupperObjects, test.skupperError)
 			assert.Assert(t, err)
 			command.Flags = &test.flags
 
@@ -427,25 +436,16 @@ func TestCmdLinkGenerate_InputToOptions(t *testing.T) {
 
 	testTable := []test{
 		{
-			name: "check options",
-			flags: common.CommandLinkGenerateFlags{
-				TlsCredentials: "secret",
-				Cost:           "1", Output: "json",
-				GenerateCredential: false,
-				Timeout:            time.Minute},
+			name:                        "check options",
+			flags:                       common.CommandLinkGenerateFlags{TlsCredentials: "secret", Cost: "1", Output: "json", GenerateCredential: false, Timeout: time.Minute},
 			expectedCost:                1,
 			expectedTlsCredentials:      "secret",
 			expectedOutput:              "json",
 			expectedGenerateCredentials: false,
 		},
 		{
-			name: "credentials are not needed",
-			flags: common.CommandLinkGenerateFlags{
-				TlsCredentials:     "",
-				Cost:               "1",
-				Output:             "json",
-				GenerateCredential: true,
-				Timeout:            time.Minute},
+			name:  "credentials are not needed",
+			flags: common.CommandLinkGenerateFlags{TlsCredentials: "", Cost: "1", Output: "json", GenerateCredential: true, Timeout: time.Minute},
 			activeSite: &v2alpha1.Site{
 
 				ObjectMeta: v1.ObjectMeta{
@@ -500,12 +500,13 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 		name              string
 		setUpMock         func(command *CmdLinkGenerate)
 		errorMessage      string
+		skupperObjects    []runtime.Object
 		skCliErrorMessage string
 	}
 
 	testTable := []test{
 		{
-			name: "runs ok without generating credentials",
+			name: "The function runs correctly without generating credentials",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -550,7 +551,7 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 			},
 		},
 		{
-			name: "runs ok generating credentials",
+			name: "The function runs correctly generating credentials",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -595,7 +596,64 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 			},
 		},
 		{
-			name: "runs fails because the output format is not supported",
+			name: "The function runs correctly without generating credentials because they already exist.",
+			setUpMock: func(command *CmdLinkGenerate) {
+				command.linkName = "my-link"
+				command.cost = 1
+				command.tlsCredentials = "secret"
+				command.output = "yaml"
+				command.generateCredential = true
+				command.activeSite = &v2alpha1.Site{
+
+					ObjectMeta: v1.ObjectMeta{
+						Name:      "the-site",
+						Namespace: "test",
+					},
+					Status: v2alpha1.SiteStatus{
+						Status: v2alpha1.Status{
+							Message: "OK",
+							Conditions: []v1.Condition{
+								{
+									Message:            "OK",
+									ObservedGeneration: 1,
+									Reason:             "OK",
+									Status:             "True",
+									Type:               "Configured",
+								},
+							},
+						},
+						Endpoints: []v2alpha1.Endpoint{
+							{
+								Name:  "inter-router",
+								Host:  "127.0.0.1",
+								Port:  "8080",
+								Group: "skupper-router-1",
+							},
+							{
+								Name:  "edge",
+								Host:  "127.0.0.1",
+								Port:  "8080",
+								Group: "skupper-router-1",
+							},
+						},
+					},
+				}
+			},
+			skupperObjects: []runtime.Object{
+				&v2alpha1.Certificate{
+					TypeMeta: v1.TypeMeta{
+						APIVersion: "skupper.io/v2alpha1",
+						Kind:       "Certificate",
+					},
+					ObjectMeta: v1.ObjectMeta{
+						Name:      "secret",
+						Namespace: "test",
+					},
+				},
+			},
+		},
+		{
+			name: "The function fails because the output format is not supported",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -638,10 +696,10 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 					},
 				}
 			},
-			errorMessage: "output format has not been specified",
+			errorMessage: "Output format is not specified",
 		},
 		{
-			name: "runs fails because the output format is not supported",
+			name: "The function fails because the output format is not supported",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -687,7 +745,7 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 			errorMessage: "format unsupported not supported",
 		},
 		{
-			name: "runs fails because active site has not endpoints configured",
+			name: "The function fails because active site has not endpoints configured",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -716,10 +774,10 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 					},
 				}
 			},
-			errorMessage: "the active site has not configured endpoints yet",
+			errorMessage: "A link cannot be generated because link access is not enabled. \n Use \"skupper site update --enable-link-access\" to enable it.",
 		},
 		{
-			name: "runs fails because there are no active site",
+			name: "The function fails because there are no active site",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -728,10 +786,10 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 				command.generateCredential = false
 				command.activeSite = nil
 			},
-			errorMessage: "there is no active site to generate the link resource file",
+			errorMessage: "There is no active site to generate the link resource file",
 		},
 		{
-			name: "runs fails because certificate could not be created",
+			name: "The function fails because certificate could not be created",
 			setUpMock: func(command *CmdLinkGenerate) {
 				command.linkName = "my-link"
 				command.cost = 1
@@ -780,7 +838,7 @@ func TestCmdLinkGenerate_Run(t *testing.T) {
 	}
 
 	for _, test := range testTable {
-		cmd, err := newCmdLinkGenerateWithMocks("test", nil, nil, test.skCliErrorMessage)
+		cmd, err := newCmdLinkGenerateWithMocks("test", nil, test.skupperObjects, test.skCliErrorMessage)
 		assert.Assert(t, err)
 
 		test.setUpMock(cmd)
@@ -801,7 +859,7 @@ func TestCmdLinkGenerate_WaitUntil(t *testing.T) {
 	type test struct {
 		name               string
 		generateCredential bool
-		generatedLink      v2alpha1.Link
+		generatedLinks     []v2alpha1.Link
 		outputType         string
 		tlsCredentials     string
 		timeout            time.Duration
@@ -830,9 +888,24 @@ func TestCmdLinkGenerate_WaitUntil(t *testing.T) {
 		{
 			name:               "bad format for the output",
 			generateCredential: false,
-			outputType:         "not supported",
-			timeout:            time.Second,
-			expectError:        true,
+			generatedLinks: []v2alpha1.Link{
+				{
+					TypeMeta: metav1.TypeMeta{
+						APIVersion: "skupper.io/v2alpha1",
+						Kind:       "Link",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "link",
+					},
+					Spec: v2alpha1.LinkSpec{
+						TlsCredentials: "credentials",
+						Cost:           1,
+					},
+				},
+			},
+			outputType:  "not supported",
+			timeout:     time.Second,
+			expectError: true,
 		},
 		{
 			name:               "the output contains the link and the secret",
@@ -906,6 +979,7 @@ func TestCmdLinkGenerate_WaitUntil(t *testing.T) {
 			command.generateCredential = test.generateCredential
 			command.tlsCredentials = test.tlsCredentials
 			command.timeout = test.timeout
+			command.generatedLinks = test.generatedLinks
 
 			err := command.WaitUntil()
 
