@@ -133,6 +133,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -177,6 +191,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -221,6 +249,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -265,6 +307,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -309,6 +365,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -353,6 +423,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -397,6 +481,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -441,6 +539,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -485,6 +597,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -529,6 +655,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
@@ -553,6 +693,9 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 								Name:      "site1",
 								Namespace: "test",
 							},
+							Spec: v2alpha1.SiteSpec{
+								LinkAccess: "local",
+							},
 							Status: v2alpha1.SiteStatus{
 								Status: v2alpha1.Status{
 									Conditions: []v1.Condition{
@@ -614,6 +757,20 @@ func TestCmdTokenIssue_ValidateInput(t *testing.T) {
 										},
 									},
 								},
+								Endpoints: []v2alpha1.Endpoint{
+									{
+										Name:  "inter-router",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+									{
+										Name:  "edge",
+										Host:  "127.0.0.1",
+										Port:  "8080",
+										Group: "skupper-router-1",
+									},
+								},
 							},
 						},
 					},
