@@ -138,14 +138,26 @@ func (m *CertificateManagerImpl) ensure(namespace string, name string, spec skup
 	key := fmt.Sprintf("%s/%s", namespace, name)
 	if current, ok := m.definitions[key]; ok {
 		changed := false
-		if mergeOwnerReferences(current.ObjectMeta.OwnerReferences, refs) {
+		if mergeOwnerReferences(&current.ObjectMeta, refs) {
 			changed = true
 		}
+		ownerRefsLength := len(current.ObjectMeta.OwnerReferences)
+		specHostsCsv := strings.Join(spec.Hosts, ",")
+		specHosts := spec.Hosts
+		if ownerRefsLength > 1 {
+			spec.Subject = current.Spec.Subject
+			specHosts = append(specHosts, current.Spec.Hosts...)
+		}
+		// merge hosts as the certificate may be shared by sources each requiring different sets of hosts:
+		spec.Hosts = getHostChanges(getPreviousHosts(current, refs), specHosts, key).apply(current.Spec.Hosts)
 		if !cmp.Equal(spec, current.Spec, compareSpecUnordered...) {
-			// merge hosts as the certificate may be shared by sources each requiring different sets of hosts:
-			hosts := getHostChanges(getPreviousHosts(current, refs), spec.Hosts, key).apply(current.Spec.Hosts)
 			current.Spec = spec
-			current.Spec.Hosts = hosts
+			if current.Annotations == nil {
+				current.Annotations = map[string]string{}
+			}
+			if len(refs) > 0 {
+				current.ObjectMeta.Annotations["internal.skupper.io/hosts-"+string(refs[0].UID)] = specHostsCsv
+			}
 			changed = true
 		}
 		if m.context != nil {
@@ -281,6 +293,9 @@ func (m *CertificateManagerImpl) updateSecret(key string, certificate *skupperv2
 		}
 		changed = true
 		secret.Data = regenerated.Data
+		if secret.Annotations == nil {
+			secret.Annotations = map[string]string{}
+		}
 		secret.Annotations["internal.skupper.io/hosts"] = strings.Join(certificate.Spec.Hosts, ",")
 	}
 	if m.context != nil && controlled {
@@ -315,7 +330,7 @@ func (m *CertificateManagerImpl) generateSecret(certificate *skupperv2alpha1.Cer
 	var secret *corev1.Secret
 	var err error
 	if certificate.Spec.Signing {
-		secret, err = certs.GenerateSecret(certificate.Name, certificate.Spec.Subject, "", 0, nil)
+		secret, err = certs.GenerateSecret(certificate.Name, certificate.Spec.Subject, nil, 0, nil)
 		if err != nil {
 			return secret, err
 		}
@@ -328,7 +343,7 @@ func (m *CertificateManagerImpl) generateSecret(certificate *skupperv2alpha1.Cer
 			return nil, fmt.Errorf("CA %q not found", caKey)
 		}
 		// TODO: handle server and client roles properly
-		secret, err = certs.GenerateSecret(certificate.Name, certificate.Spec.Subject, strings.Join(certificate.Spec.Hosts, ","), expiration, ca)
+		secret, err = certs.GenerateSecret(certificate.Name, certificate.Spec.Subject, certificate.Spec.Hosts, expiration, ca)
 		if err != nil {
 			return nil, err
 		}
@@ -447,9 +462,10 @@ func ownerReferences(cert *skupperv2alpha1.Certificate) []metav1.OwnerReference
 	}
 }
 
-func mergeOwnerReferences(original []metav1.OwnerReference, added []metav1.OwnerReference) bool {
+func mergeOwnerReferences(obj *metav1.ObjectMeta, added []metav1.OwnerReference) bool {
 	changed := false
 	byUid := map[types.UID]metav1.OwnerReference{}
+	original := obj.OwnerReferences
 	for _, ref := range original {
 		byUid[ref.UID] = ref
 	}
@@ -459,6 +475,9 @@ func mergeOwnerReferences(original []metav1.OwnerReference, added []metav1.Owner
 			changed = true
 		}
 	}
+	if changed {
+		obj.OwnerReferences = original
+	}
 	return changed
 }
 
