@@ -35,7 +35,7 @@ func NewExtendedBindings(controller *watchers.EventProcessor, profilePath string
 			slog.String("component", "kube.site.attached_connector"),
 		),
 	}
-
+	eb.bindings.SetListenerConfiguration(eb.updateBridgeConfigForListener)
 	return eb
 }
 
@@ -165,6 +165,9 @@ func (a *ExtendedBindings) updateBridgeConfigForConnector(siteId string, connect
 }
 
 func (a *ExtendedBindings) updateBridgeConfigForListener(siteId string, listener *skupperv2alpha1.Listener, config *qdr.BridgeConfig) {
+	if a.mapping == nil {
+		a.mapping = qdr.RecoverPortMapping(nil)
+	}
 	if port, err := a.mapping.GetPortForKey(listener.Name); err == nil {
 		site.UpdateBridgeConfigForListenerWithHostAndPort(siteId, listener, "", port, config)
 	} else {
