@@ -2,12 +2,13 @@ package site
 
 import (
 	"context"
+	"log/slog"
 	"testing"
 
 	"github.com/skupperproject/skupper/internal/kube/certificates"
-	internalclient "github.com/skupperproject/skupper/internal/kube/client"
 	fakeclient "github.com/skupperproject/skupper/internal/kube/client/fake"
 	"github.com/skupperproject/skupper/internal/kube/securedaccess"
+	"github.com/skupperproject/skupper/internal/kube/watchers"
 	"github.com/skupperproject/skupper/internal/qdr"
 	site1 "github.com/skupperproject/skupper/internal/site"
 	"github.com/skupperproject/skupper/internal/version"
@@ -18,7 +19,6 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"log/slog"
 )
 
 func TestSite_Recover(t *testing.T) {
@@ -548,6 +548,40 @@ func TestSite_CheckLink(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "link - site initialized later",
+			args: args{
+				name: "link1",
+				linkconfig: &skupperv2alpha1.Link{
+					ObjectMeta: v1.ObjectMeta{
+						Name:      "link1",
+						Namespace: "test",
+						UID:       "8a96ffdf-403b-4e4a-83a8-97d3d459adb6",
+					},
+					Spec: skupperv2alpha1.LinkSpec{
+						Cost: 1,
+						Endpoints: []skupperv2alpha1.Endpoint{
+							{
+								Name: string(qdr.RoleInterRouter),
+								Host: "10.10.10.1",
+								Port: "55671",
+							},
+						},
+					},
+				},
+			},
+			want:      "post-initialized",
+			wantErr:   false,
+			wantLinks: 1,
+			skupperObjects: []runtime.Object{
+				&skupperv2alpha1.Link{
+					ObjectMeta: v1.ObjectMeta{
+						Name:      "link1",
+						Namespace: "test",
+					},
+				},
+			},
+		},
 		{
 			name: "link - not found",
 			args: args{
@@ -677,6 +711,17 @@ func TestSite_CheckLink(t *testing.T) {
 				if len(s.links) != 0 {
 					t.Errorf("Site.CheckLink() link not removed")
 				}
+			} else if tt.want == "post-initialized" {
+				existing := s.links[tt.args.name]
+				assert.Equal(t, false, existing.Definition().IsConfigured())
+				s.initialised = true
+				err = createRouterConfigMock(s)
+				assert.Assert(t, err)
+				if err := s.CheckLink(tt.args.name, tt.args.linkconfig); (err != nil) != tt.wantErr {
+					t.Errorf("Site.CheckLink() error = %v, wantErr %v", err, tt.skupperErrorMessage)
+				}
+				existing = s.links[tt.args.name]
+				assert.Equal(t, true, existing.Definition().IsConfigured())
 			} else {
 				// router not initialized
 				numLinks := len(s.links)
@@ -1005,7 +1050,7 @@ func Test_CheckSecuredAccess(t *testing.T) {
 				if s.linkAccess["skupper-router"].Spec.AccessType == "loadbalancer" {
 					t.Errorf("Site.CheckSecuredAccess() linkAccess not updated")
 				}
-				// TBD adds to code coverge but doesn't return error if failed
+				// TBD adds to code coverage but doesn't return error if failed
 				if err = s.checkSecuredAccess(); err != nil {
 					t.Errorf("Site.CheckSecuredAccess() linkAccess not updated")
 				}
@@ -1037,9 +1082,9 @@ func newSiteMocks(namespace string, k8sObjects []runtime.Object, skupperObjects
 		return nil, err
 	}
 
-	controller := internalclient.NewController("test", client)
+	controller := watchers.NewEventProcessor("test", client)
 	newSite := &Site{
-		controller: controller,
+		clients:    controller,
 		bindings:   NewExtendedBindings(controller, ""),
 		links:      make(map[string]*site1.Link),
 		errors:     make(map[string]string),
